@@ -88,7 +88,7 @@ import Numeric.Natural (Natural)
 import Data.Coerce (Coercible)
 import Data.Type.Coercion(Coercion(..))
 import Data.Type.Equality (type (~~))
-import qualified Data.Type.Equality.Hetero as Hetero
+import qualified Data.Type.Equality as Hetero
 import Type.Reflection (TypeRep, typeRepKind, withTypeable)
 import Data.Boring (Boring (..))
 
@@ -110,7 +110,6 @@ import Data.Boring (Boring (..))
 --
 data Dict :: Constraint -> * where
   Dict :: a => Dict a
-  deriving Typeable
 
 deriving stock instance (Typeable p, p) => Data (Dict p)
 deriving stock instance Eq (Dict a)
